////////////////////////////////////////////////////////////////////////////////
//
// Fracter - A simple Mandelbrot Set viewer.
//
// Copyright (C) 2010 Sarah Eris Horsley Caffee
//
// This file is part of Fracter.
//
// Fracter is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
//
// EventHandler.h
// EventHandler class definition.  This is a virtual class that is meant to be
// an interface implemented by an application class.  It does, though, provide
// default implementations of it's methods so that unused events can be quietly
// ignored.
//
////////////////////////////////////////////////////////////////////////////////

#ifndef EVENTHANDLER_H
#define EVENTHANDLER_H

#include "SDL.h"

class EventHandler
   {
   public:

   EventHandler();
   virtual ~EventHandler();

   virtual void on_event(SDL_Event * event);

   // Active events
   virtual void on_MouseFocus();
   virtual void on_MouseBlur();
   virtual void on_InputFocus();
   virtual void on_InputBlur();
   virtual void on_Minimize();
   virtual void on_Restore();


   // Keyboard events
   virtual void on_KeyDown(SDL_KeyboardEvent key);
   virtual void on_KeyUp(SDL_KeyboardEvent key);

   // Mouse events
   virtual void on_MouseMove(SDL_MouseMotionEvent motion);
   virtual void on_LButtonDown(SDL_MouseButtonEvent button);
   virtual void on_LButtonUp(SDL_MouseButtonEvent button);
   virtual void on_RButtonDown(SDL_MouseButtonEvent button);
   virtual void on_RButtonUp(SDL_MouseButtonEvent button);
   virtual void on_MButtonDown(SDL_MouseButtonEvent button);
   virtual void on_MButtonUp(SDL_MouseButtonEvent button);
   virtual void on_MouseWheelDown(SDL_MouseButtonEvent motion);
   virtual void on_MouseWheelUp(SDL_MouseButtonEvent motion);

   // Joystick events
   virtual void on_JoyAxis(SDL_JoyAxisEvent jaxis);
   virtual void on_JoyButtonDown(SDL_JoyButtonEvent jbutton);
   virtual void on_JoyButtonUp(SDL_JoyButtonEvent jbutton);
   virtual void on_JoyHat(SDL_JoyHatEvent jhat);
   virtual void on_JoyBall(SDL_JoyBallEvent jball);

   // Misc events
   virtual void on_Resize(SDL_ResizeEvent resize);
   virtual void on_Expose();
   virtual void on_Quit();
   virtual void on_User(SDL_UserEvent user);
   virtual void on_SysWM(SDL_SysWMEvent syswm);

   };

#endif
